Learn R Programming

maidr (version 0.1.2)

.maidr_patching_env: Base R Function Patching System

Description

This module provides function patching capabilities for Base R plotting functions. It intercepts Base R plotting calls and records them for processing by the MAIDR system.

Usage

.maidr_patching_env

Arguments

Format

An object of class environment of length 4.