Learn R Programming

maidr (version 0.1.2)

BaseRBoxplotLayerProcessor: Base R Boxplot Layer Processor

Description

Processes Base R boxplot layers by extracting statistical summaries and generating selectors for boxplot components.

Arguments

Super class

maidr::LayerProcessor -> BaseRBoxplotLayerProcessor

Methods

Inherited methods


Method process()

Usage

BaseRBoxplotLayerProcessor$process(
  plot,
  layout,
  built = NULL,
  gt = NULL,
  layer_info = NULL
)


Method extract_data()

Usage

BaseRBoxplotLayerProcessor$extract_data(layer_info)


Method generate_selectors()

Usage

BaseRBoxplotLayerProcessor$generate_selectors(
  layer_info,
  gt = NULL,
  extracted_data = NULL
)


Method extract_axis_titles()

Usage

BaseRBoxplotLayerProcessor$extract_axis_titles(layer_info)


Method extract_main_title()

Usage

BaseRBoxplotLayerProcessor$extract_main_title(layer_info)


Method determine_orientation()

Usage

BaseRBoxplotLayerProcessor$determine_orientation(layer_info)


Method clone()

The objects of this class are cloneable with this method.

Usage

BaseRBoxplotLayerProcessor$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.