Learn R Programming

maidr (version 0.1.2)

BaseRStackedBarLayerProcessor: Base R Stacked Bar Layer Processor

Description

Processes Base R stacked bar plot layers intercepted via the patching system. Assumes sorting by x (columns) and then fill (rows) has already been applied by the `SortingPatcher`.

Arguments

Super class

maidr::LayerProcessor -> BaseRStackedBarLayerProcessor

Methods

Inherited methods


Method process()

Usage

BaseRStackedBarLayerProcessor$process(
  plot,
  layout,
  built = NULL,
  gt = NULL,
  scale_mapping = NULL,
  grob_id = NULL,
  panel_id = NULL,
  panel_ctx = NULL,
  layer_info = NULL
)


Method needs_reordering()

Usage

BaseRStackedBarLayerProcessor$needs_reordering()


Method extract_data()

Usage

BaseRStackedBarLayerProcessor$extract_data(layer_info)


Method extract_axis_titles()

Usage

BaseRStackedBarLayerProcessor$extract_axis_titles(layer_info)


Method extract_main_title()

Usage

BaseRStackedBarLayerProcessor$extract_main_title(layer_info)


Method generate_selectors()

Usage

BaseRStackedBarLayerProcessor$generate_selectors(layer_info, gt = NULL)


Method find_rect_groups()

Usage

BaseRStackedBarLayerProcessor$find_rect_groups(grob, call_index)


Method clone()

The objects of this class are cloneable with this method.

Usage

BaseRStackedBarLayerProcessor$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.