Learn R Programming

maidr (version 0.1.2)

apply_barplot_sorting: Apply sorting logic to barplot arguments for consistent visual ordering

Description

Apply sorting logic to barplot arguments for consistent visual ordering

Usage

apply_barplot_sorting(args)

Value

Modified arguments with sorted matrix data

Arguments

args

List of arguments passed to barplot