Learn R Programming

maidr (version 0.1.2)

create_axis_wrapper: Create enhanced wrapper for axis to capture scales:: format config

Description

This wrapper intercepts axis() calls and checks if the labels argument is a scales:: label function (closure). If so, it extracts the format configuration before applying the function to get the actual labels.

Usage

create_axis_wrapper(original_function)

Value

Enhanced wrapped function

Arguments

original_function

Original axis function