Suppresses the default printing of density return values in RMarkdown. The density() function is not patched (it's in stats, not graphics), so we need this method to suppress its output.
knit_print.density(x, options = list(), ...)An invisible empty string
A density object (from density())
Chunk options from knitr
Additional arguments (ignored)