Learn R Programming

maidr (version 0.1.2)

knit_print.histogram: Custom knit_print Method for histogram Objects

Description

Suppresses the default printing of histogram return values in RMarkdown. The plot is already rendered via the plot hook; this prevents the histogram object structure from being printed as text output.

Usage

knit_print.histogram(x, options = list(), ...)

Value

An invisible empty string

Arguments

x

A histogram object (from hist())

options

Chunk options from knitr

...

Additional arguments (ignored)