Learn R Programming

maidr (version 0.1.2)

maidr_on: Enable MAIDR Rendering in RMarkdown

Description

Enables automatic accessible rendering of ggplot2 and Base R plots in RMarkdown documents. When enabled, plots are automatically converted to interactive MAIDR widgets with keyboard navigation and screen reader support.

Usage

maidr_on()

Arguments

Value

Invisible TRUE on success

See Also

[maidr_off()] to disable MAIDR rendering

Examples

Run this code
# \donttest{
# In RMarkdown setup chunk:
library(maidr)
maidr_on()

# Now all plots render as accessible MAIDR widgets
library(ggplot2)
ggplot(mtcars, aes(x = factor(cyl))) +
  geom_bar()

barplot(table(mtcars$cyl))
# }

Run the code above in your browser using DataLab