Learn R Programming

maidr (version 0.1.2)

open_maidr_temp_device: Open a temporary device to suppress default graphics window

Description

Called by wrappers when no device is open to prevent R from opening the default interactive graphics device.

Usage

open_maidr_temp_device()

Arguments

Value

The device ID of the temp device