Learn R Programming

maidr (version 0.1.2)

r_date_format_to_js_function: Convert R Date Format to JavaScript Function

Description

Creates a JavaScript function string that formats dates according to an R strftime format string. Used for complex date formats that cannot be represented by Intl.DateTimeFormat options alone.

Usage

r_date_format_to_js_function(format, tz = "UTC")

Value

JavaScript function body string

Arguments

format

R date format string

tz

Timezone