Learn R Programming

maidr (version 0.1.2)

replay_to_native_device: Replay Base R plot to native graphics device

Description

For unsupported plots, close the temp device and replay the plot calls to the native graphics device.

Usage

replay_to_native_device(device_id = grDevices::dev.cur())

Value

NULL (invisible)

Arguments

device_id

The device ID to get plot calls from