powered by
This module provides function patching capabilities for Base R plotting functions. It intercepts Base R plotting calls and records them for processing by the MAIDR system.
.maidr_patching_env
An object of class environment of length 4.
environment