Learn R Programming

maidr (version 0.1.2)

BaseRBarplotLayerProcessor: Base R Bar Plot Layer Processor

Description

Base R Bar Plot Layer Processor

Base R Bar Plot Layer Processor

Arguments

Super class

maidr::LayerProcessor -> BaseRBarplotLayerProcessor

Methods

Inherited methods


Method process()

Usage

BaseRBarplotLayerProcessor$process(
  plot,
  layout,
  built = NULL,
  gt = NULL,
  scale_mapping = NULL,
  grob_id = NULL,
  panel_id = NULL,
  panel_ctx = NULL,
  layer_info = NULL
)


Method needs_reordering()

Usage

BaseRBarplotLayerProcessor$needs_reordering()


Method extract_data()

Usage

BaseRBarplotLayerProcessor$extract_data(layer_info)


Method extract_axis_titles()

Usage

BaseRBarplotLayerProcessor$extract_axis_titles(layer_info)


Method extract_main_title()

Usage

BaseRBarplotLayerProcessor$extract_main_title(layer_info)


Method generate_selectors()

Usage

BaseRBarplotLayerProcessor$generate_selectors(layer_info, gt = NULL)


Method find_rect_grobs()

Recursively find rect grobs in the grob tree (like ggplot2 does)

Usage

BaseRBarplotLayerProcessor$find_rect_grobs(grob, call_index)

Arguments

grob

The grob tree to search

call_index

The plot call index to match

Returns

Character vector of grob names


Method generate_selectors_from_grob()

Generate selectors from grob tree (like ggplot2 does)

Usage

BaseRBarplotLayerProcessor$generate_selectors_from_grob(grob, call_index)

Arguments

grob

The grob tree to search

call_index

The plot call index

Returns

List of selectors


Method clone()

The objects of this class are cloneable with this method.

Usage

BaseRBarplotLayerProcessor$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.

Details

Processes Base R bar plot layers based on recorded plot calls