Base R Bar Plot Layer Processor
Base R Bar Plot Layer Processor
maidr::LayerProcessor -> BaseRBarplotLayerProcessor
Inherited methods
process()BaseRBarplotLayerProcessor$process(
plot,
layout,
built = NULL,
gt = NULL,
scale_mapping = NULL,
grob_id = NULL,
panel_id = NULL,
panel_ctx = NULL,
layer_info = NULL
)
needs_reordering()BaseRBarplotLayerProcessor$needs_reordering()
extract_data()BaseRBarplotLayerProcessor$extract_data(layer_info)
extract_axis_titles()BaseRBarplotLayerProcessor$extract_axis_titles(layer_info)
extract_main_title()BaseRBarplotLayerProcessor$extract_main_title(layer_info)
generate_selectors()BaseRBarplotLayerProcessor$generate_selectors(layer_info, gt = NULL)
find_rect_grobs()Recursively find rect grobs in the grob tree (like ggplot2 does)
BaseRBarplotLayerProcessor$find_rect_grobs(grob, call_index)grobThe grob tree to search
call_indexThe plot call index to match
Character vector of grob names
generate_selectors_from_grob()Generate selectors from grob tree (like ggplot2 does)
BaseRBarplotLayerProcessor$generate_selectors_from_grob(grob, call_index)grobThe grob tree to search
call_indexThe plot call index
List of selectors
clone()The objects of this class are cloneable with this method.
BaseRBarplotLayerProcessor$clone(deep = FALSE)deepWhether to make a deep clone.
Processes Base R bar plot layers based on recorded plot calls