Learn R Programming

maidr (version 0.1.2)

BaseRPatcher: Base R Patch Architecture

Description

Modular system for patching Base R plotting functions with chain of responsibility pattern

Arguments

Methods


Method can_patch()

Usage

BaseRPatcher$can_patch(function_name, args)


Method apply_patch()

Usage

BaseRPatcher$apply_patch(function_name, args)


Method get_name()

Usage

BaseRPatcher$get_name()


Method clone()

The objects of this class are cloneable with this method.

Usage

BaseRPatcher$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.