Modular system for patching Base R plotting functions with chain of responsibility pattern
can_patch()BaseRPatcher$can_patch(function_name, args)
apply_patch()BaseRPatcher$apply_patch(function_name, args)
get_name()BaseRPatcher$get_name()
clone()The objects of this class are cloneable with this method.
BaseRPatcher$clone(deep = FALSE)deepWhether to make a deep clone.