Base R Plot Orchestrator Class
Base R Plot Orchestrator Class
plot_callsList of recorded Base R plot calls
layersList of detected layer information
layer_processorsList of layer-specific processors
combined_dataCombined data from all layers
combined_selectorsCombined selectors from all layers
layoutLayout information from the plot
plot_callsList of recorded Base R plot calls
layersList of detected layer information
layer_processorsList of layer-specific processors
combined_dataCombined data from all layers
combined_selectorsCombined selectors from all layers
layoutLayout information from the plot
new()BaseRPlotOrchestrator$new(device_id = grDevices::dev.cur())
detect_layers()BaseRPlotOrchestrator$detect_layers()
analyze_single_layer()BaseRPlotOrchestrator$analyze_single_layer(
plot_call,
layer_index,
group = NULL
)
create_layer_processors()BaseRPlotOrchestrator$create_layer_processors()
create_layer_processor()BaseRPlotOrchestrator$create_layer_processor(layer_info)
create_unified_layer_processor()BaseRPlotOrchestrator$create_unified_layer_processor(layer_info)layer_infoLayer information
Layer processor instance Extract Format Configuration from axis() Calls
Scans logged axis() calls for format config stored by the axis wrapper. The wrapper stores .maidr_format_config when labels is a scales:: function.
process_layers()BaseRPlotOrchestrator$process_layers()
extract_format_config_from_axis_calls()BaseRPlotOrchestrator$extract_format_config_from_axis_calls()A list with x and/or y format configurations, or NULL
extract_layout()BaseRPlotOrchestrator$extract_layout()
combine_layer_results()BaseRPlotOrchestrator$combine_layer_results(layer_results)
generate_maidr_data()BaseRPlotOrchestrator$generate_maidr_data()
get_layout()BaseRPlotOrchestrator$get_layout()
get_combined_data()BaseRPlotOrchestrator$get_combined_data()
get_layer_processors()BaseRPlotOrchestrator$get_layer_processors()
get_layers()BaseRPlotOrchestrator$get_layers()
get_plot_calls()BaseRPlotOrchestrator$get_plot_calls()
get_gtable()BaseRPlotOrchestrator$get_gtable()
get_grob_for_layer()BaseRPlotOrchestrator$get_grob_for_layer(layer_index)
has_unsupported_layers()Check if any HIGH-level layers are unsupported (unknown type)
BaseRPlotOrchestrator$has_unsupported_layers()Logical indicating if there are unsupported layers
should_fallback()Determine if the plot should fall back to image rendering
BaseRPlotOrchestrator$should_fallback()Logical indicating if fallback should be used
clone()The objects of this class are cloneable with this method.
BaseRPlotOrchestrator$clone(deep = FALSE)deepWhether to make a deep clone.
This class orchestrates the detection and processing of multiple layers in Base R plots. It analyzes each recorded plot call individually and combines the results into a comprehensive interactive plot.