Plot Orchestrator Class
Plot Orchestrator Class
plotThe ggplot2 object being processed
layersList of detected layer information
layer_processorsList of layer-specific processors
combined_dataCombined data from all layers
combined_selectorsCombined selectors from all layers
layoutLayout information from the plot
plotThe ggplot2 object being processed
layersList of detected layer information
layer_processorsList of layer-specific processors
combined_dataCombined data from all layers
combined_selectorsCombined selectors from all layers
layoutLayout information from the plot
new()Ggplot2PlotOrchestrator$new(plot)
detect_layers()Ggplot2PlotOrchestrator$detect_layers()
analyze_single_layer()Ggplot2PlotOrchestrator$analyze_single_layer(layer, layer_index)
determine_layer_type()Ggplot2PlotOrchestrator$determine_layer_type(plot, layer_index)
create_layer_processors()Ggplot2PlotOrchestrator$create_layer_processors()
create_layer_processor()Ggplot2PlotOrchestrator$create_layer_processor(layer_info)
create_unified_layer_processor()Ggplot2PlotOrchestrator$create_unified_layer_processor(layer_info)layer_infoLayer information
Layer processor instance
process_layers()Ggplot2PlotOrchestrator$process_layers()
extract_layout()Ggplot2PlotOrchestrator$extract_layout()
combine_layer_results()Ggplot2PlotOrchestrator$combine_layer_results(layer_results)
generate_maidr_data()Ggplot2PlotOrchestrator$generate_maidr_data()
get_gtable()Ggplot2PlotOrchestrator$get_gtable()
get_layout()Ggplot2PlotOrchestrator$get_layout()
get_combined_data()Ggplot2PlotOrchestrator$get_combined_data()
get_layer_processors()Ggplot2PlotOrchestrator$get_layer_processors()
get_layers()Ggplot2PlotOrchestrator$get_layers()
is_patchwork_plot()Check if the plot is a patchwork composition
Ggplot2PlotOrchestrator$is_patchwork_plot()Logical indicating if the plot is a patchwork plot
is_faceted_plot()Check if the plot is faceted
Ggplot2PlotOrchestrator$is_faceted_plot()Logical indicating if the plot is faceted
process_faceted_plot()Process a faceted plot using utility functions
Ggplot2PlotOrchestrator$process_faceted_plot()NULL (sets internal state)
process_patchwork_plot()Process a patchwork multipanel plot using utility functions
Ggplot2PlotOrchestrator$process_patchwork_plot()NULL (sets internal state)
has_unsupported_layers()Check if any layers are unsupported (unknown type)
Ggplot2PlotOrchestrator$has_unsupported_layers()Logical indicating if there are unsupported layers
should_fallback()Determine if the plot should fall back to image rendering
Ggplot2PlotOrchestrator$should_fallback()Logical indicating if fallback should be used
clone()The objects of this class are cloneable with this method.
Ggplot2PlotOrchestrator$clone(deep = FALSE)deepWhether to make a deep clone.
This class orchestrates the detection and processing of multiple layers in a ggplot2 object. It analyzes each layer individually and combines the results into a comprehensive interactive plot.