Processes scatter plot layers (geom_point) to extract point data and generate selectors for individual points in the SVG structure.
maidr::LayerProcessor -> Ggplot2PointLayerProcessor
Inherited methods
maidr::LayerProcessor$apply_scale_mapping()maidr::LayerProcessor$extract_layer_axes()maidr::LayerProcessor$get_last_result()maidr::LayerProcessor$get_layer_index()maidr::LayerProcessor$initialize()maidr::LayerProcessor$needs_reordering()maidr::LayerProcessor$reorder_layer_data()maidr::LayerProcessor$set_last_result()
process()Ggplot2PointLayerProcessor$process(
plot,
layout,
built = NULL,
gt = NULL,
scale_mapping = NULL,
grob_id = NULL,
panel_id = NULL,
panel_ctx = NULL
)plotThe ggplot2 object
layoutLayout information
builtBuilt plot data (optional)
gtGtable object (optional)
scale_mappingScale mapping for faceted plots (optional)
grob_idGrob ID for faceted plots (optional)
panel_idPanel ID for faceted plots (optional)
List with data and selectors Extract axis labels from the plot
extract_axes_labels()Ggplot2PointLayerProcessor$extract_axes_labels(plot, built = NULL)plotThe ggplot2 object
builtBuilt plot data (optional)
List with x and y axis labels Extract data from point layer
extract_data()Ggplot2PointLayerProcessor$extract_data(
plot,
built = NULL,
scale_mapping = NULL,
panel_id = NULL
)plotThe ggplot2 object
builtBuilt plot data (optional)
scale_mappingScale mapping for faceted plots (optional)
panel_idPanel ID for faceted plots (optional)
List with points array and color information Generate selectors for point elements
generate_selectors()Ggplot2PointLayerProcessor$generate_selectors(
plot,
gt = NULL,
grob_id = NULL,
panel_ctx = NULL
)plotThe ggplot2 object
gtGtable object (optional)
grob_idGrob ID for faceted plots (optional)
List of selectors Find the main panel grob
find_panel_grob()Ggplot2PointLayerProcessor$find_panel_grob(gt)gtThe gtable to search
The panel grob or NULL Find children by type pattern
find_children_by_type()Ggplot2PointLayerProcessor$find_children_by_type(grob, type_pattern)grobThe grob to search
type_patternPattern to match
List of matching children
clone()The objects of this class are cloneable with this method.
Ggplot2PointLayerProcessor$clone(deep = FALSE)deepWhether to make a deep clone.