Learn R Programming

maidr (version 0.1.2)

Ggplot2UnknownLayerProcessor: Unknown Layer Processor

Description

Handles unsupported layer types gracefully by returning empty data

Arguments

Super class

maidr::LayerProcessor -> Ggplot2UnknownLayerProcessor

Methods

Inherited methods


Method process()

Usage

Ggplot2UnknownLayerProcessor$process(
  plot,
  layout,
  built = NULL,
  gt = NULL,
  scale_mapping = NULL,
  grob_id = NULL,
  panel_ctx = NULL
)


Method extract_data()

Usage

Ggplot2UnknownLayerProcessor$extract_data(
  plot,
  built = NULL,
  scale_mapping = NULL
)


Method generate_selectors()

Usage

Ggplot2UnknownLayerProcessor$generate_selectors(
  plot,
  gt = NULL,
  grob_id = NULL,
  panel_ctx = NULL
)


Method clone()

The objects of this class are cloneable with this method.

Usage

Ggplot2UnknownLayerProcessor$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.