Handles unsupported layer types gracefully by returning empty data
maidr::LayerProcessor -> Ggplot2UnknownLayerProcessor
Inherited methods
maidr::LayerProcessor$apply_scale_mapping()maidr::LayerProcessor$extract_layer_axes()maidr::LayerProcessor$get_last_result()maidr::LayerProcessor$get_layer_index()maidr::LayerProcessor$initialize()maidr::LayerProcessor$needs_reordering()maidr::LayerProcessor$reorder_layer_data()maidr::LayerProcessor$set_last_result()
process()Ggplot2UnknownLayerProcessor$process(
plot,
layout,
built = NULL,
gt = NULL,
scale_mapping = NULL,
grob_id = NULL,
panel_ctx = NULL
)
extract_data()Ggplot2UnknownLayerProcessor$extract_data(
plot,
built = NULL,
scale_mapping = NULL
)
generate_selectors()Ggplot2UnknownLayerProcessor$generate_selectors(
plot,
gt = NULL,
grob_id = NULL,
panel_ctx = NULL
)
clone()The objects of this class are cloneable with this method.
Ggplot2UnknownLayerProcessor$clone(deep = FALSE)deepWhether to make a deep clone.