Abstract base class for creating processors specific to different plotting systems. Each plotting system should have its own factory implementation that creates the appropriate processors for different plot types.
An R6 class
create_processor()ProcessorFactory$create_processor(plot_type, plot_object)plot_typeThe type of plot (e.g., "bar", "line", "point")
plot_objectThe plot object to process
Processor instance for the specified plot type Abstract method to get list of supported plot types
get_supported_types()ProcessorFactory$get_supported_types()Character vector of supported plot types Check if a plot type is supported by this factory
supports_plot_type()ProcessorFactory$supports_plot_type(plot_type)plot_typeThe plot type to check
TRUE if supported, FALSE otherwise Get system name (should be overridden by subclasses)
get_system_name()ProcessorFactory$get_system_name()System name string
clone()The objects of this class are cloneable with this method.
ProcessorFactory$clone(deep = FALSE)deepWhether to make a deep clone.