System Adapter Base Class
System Adapter Base Class
An R6 class
system_nameName of the plotting system
new()Initialize the adapter
SystemAdapter$new(system_name)system_nameName of the plotting system Abstract method to check if this adapter can handle a plot object
can_handle()SystemAdapter$can_handle(plot_object)plot_objectThe plot object to check
TRUE if this adapter can handle the object, FALSE otherwise Abstract method to create an orchestrator for this system
create_orchestrator()SystemAdapter$create_orchestrator(plot_object)plot_objectThe plot object to process
Orchestrator instance specific to this system
clone()The objects of this class are cloneable with this method.
SystemAdapter$clone(deep = FALSE)deepWhether to make a deep clone.
Abstract base class for adapting different plotting systems to the unified maidr interface. Each plotting system (ggplot2, base R, lattice, etc.) should have its own adapter implementation.