powered by
This module tracks the plotting state for each graphics device, including active plot index, panel configuration, and plot grouping.
get_device_state(device_id = grDevices::dev.cur())
Device state list
Graphics device ID